@@ -617,8 +617,8 @@ class TestrailLibrary:
                 #print(f'Deleting attachment {attachment["name"]} from run {run_id}')
                 logger.info(f'Deleting attachment {attachment["name"]} from run {run_id}')
                 try:
-                    deleted_response = self.delete_attachment(attachment)
-                    deleted.append(deleted_response)
+                    response = self.delete_attachment(attachment)
+                    deleted.append(attachment["name"])
                 except Exception as e:
                     logger.error(e)  
         logger.info(deleted)      
