@@ -697,11 +697,13 @@ class BasicTests(unittest.TestCase):
         run = RunsResponse(1).runs[0]
         attachments = AttachmentsResponse(10)
         mock_get.return_value = attachments.get 
-        deleted_response = [{"attachment_id": attachments.attachments[i].get("id")} 
-                        for i in range(len(attachments.attachments[:-7]))]
-        mock_post.side_effect = deleted_response
+        attachments_sorted = sorted(attachments.attachments, key=lambda x: x.get("created_on"))
+        exp_response = [attachments_sorted[i] for i in range(len(attachments_sorted[:-7]))]
+        expected_response = list(map(lambda x: x.get("name"), exp_response))
+        deleted_response = None
+        mock_post.return_value = deleted_response
         res = self.tr.delete_attachments_cleanup(run.get("id"))
-        self.assertEqual(res, deleted_response)
+        self.assertEqual(res, expected_response)
 
 if __name__ == "__main__":
     unittest.main()
